@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.1101';
+our $VERSION = '0.1102';
 
 use Moo;
 use strictures 2;
@@ -265,12 +265,12 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.1101
+version 0.1102
 
 =head1 SYNOPSIS
 
   use Lingua::EN::Opinion;
-  my $opinion = Lingua::EN::Opinion->new( file => '/some/file.txt' );
+  my $opinion = Lingua::EN::Opinion->new( file => '/some/file.txt', stem => 1 );
   $opinion->analyze();
   my $score = $opinion->averaged_score(5);
   my $sentiment = $opinion->get_word('foo');
@@ -284,7 +284,7 @@ version 0.1101
 
 =head1 DESCRIPTION
 
-A C<Lingua::EN::Opinion> measures the emotional sentiment of text.
+A C<Lingua::EN::Opinion> object measures the emotional sentiment of text.
 
 Please see the F<eg/> and F<t/> scripts for example usage.
 
@@ -312,6 +312,8 @@ of the provided file or text.
 
 * These modules must be installed and working to use this feature.
 
+This is a computed result.  Providing this in the constructor will be ignored.
+
 =head2 sentences
 
 Computed result.
@@ -356,7 +358,7 @@ in the analyzed score.
 
   $opinion->nrc_sentiment();
 
-Compute the NRC sentiment of the given text by sentences.
+Compute the NRC sentiment of the given text.
 
 This is given by a 0/1 list of these 10 emotional elements:
 
@@ -409,6 +411,8 @@ L<Lingua::EN::Sentence>
 
 L<Statistics::Lite>
 
+L<Try::Tiny>
+
 L<https://www.cs.uic.edu/~liub/FBS/sentiment-analysis.html#lexicon>
 
 L<http://saifmohammad.com/WebPages/NRC-Emotion-Lexicon.htm>
